# Syntactical

**_The programing language of the future._**

### What is Syntactical?

Syntactical is a programming language made with Python, that is meant to be like Python, but with better syntax.

### Documentation

Documentation is under construction. The current documentation can be found [here](https://github.com/thecoolguy62aws/syntactical/wiki).
